NMCA - New Mexico Appellate Reports

New Mexico Court of Appeals – New Mexico Appellate Reports – 2013
| Sorting options — The authenticated opinions may be sorted by "Filing Date", "Short Title", "Opinion Number", or "Docket No."
| Click on the column name/header — the opinions will sort in descending/ascending order. Note that the Short Title
| column contains the full text of the official final version of an opinion in PDF format.
Filing Date | Short Title | Opinion Number | Docket No.
--- | --- | --- | ---
11/02/2012 | Vinyard v. Palo Alto, Inc. | 2013-NMCA-001 | 30,846
08/09/2012 | State v. Vandever | 2013-NMCA-002 | 30,842
09/20/2012 | Encinias v. Whitener Law Firm, P.A. | 2013-NMCA-003 | 30,106
09/27/2012 | Estate of Lajeuenesse v. UNM Bd. of Regents | 2013-NMCA-004 | 30,969
10/04/2012 | State v. Garcia | 2013-NMCA-005 | 31,470
10/11/2012 | Bargman v. Skilled Healthcare Grp., Inc. | 2013-NMCA-006 | 31,088
10/24/2012 | Gomez v. Jones-Wilson | 2013-NMCA-007 | 31,085
11/01/2012 | Fastbucks of Roswell, N.M., LLC v. King | 2013-NMCA-008 | 31,007
10/02/2012 | Acosta v. Shell W. Expl. & Prod., Inc. | 2013-NMCA-009 | 29,502
10/22/2012 | Lu v. Educ. Trust Bd. of N.M. | 2013-NMCA-010 | 31,363
10/24/2012 | State v. Leon | 2013-NMCA-011 | 31,067
10/29/2012 | AFSCME Council 18 v. City of Albuquerque | 2013-NMCA-012 | 30,927
11/21/2012 | Am. Nat'l. Prop. & Cas. Co. v. Cleveland | 2013-NMCA-013 | 30,164
08/16/2012 | Ruppelt v. Laurel Healthcare Providers, L.L.C. | 2013-NMCA-014 | 30,191
08/29/2012 | Bernalillo Bd. of Co. Comm'rs v. Benavidez | 2013-NMCA-015 | 29,853
09/19/2012 | State v. Valdez | 2013-NMCA-016 | 31,164
09/20/2012 | Helena Chem. Co. v. Uribe | 2013-NMCA-017 | 31,080; 30,792
10/30/2012 | Assoc. Home & RV Sales, Inc. v. Bank of Belen | 2013-NMCA-018 | 30,829
11/14/2012 | Journeyman Constr., L.P. v. Premier Hospitality II | 2013-NMCA-019 | 30,773
10/12/2012 | Rodriguez v. Del Sol Shopping Ctr. Assoc., L.P. | 2013-NMCA-020 | 30,421; 30,578
10/19/2012 | Safeway, Inc. v. Rooter 2000 Plumbing & Drain SSS | 2013-NMCA-021 | 30,196
10/24/2012 | M.R. v. Serenicare Funeral Home, L.L.C. | 2013-NMCA-022 | 30,879
10/24/2012 | State of N.M. ex rel. OSE v. Elephant Butte Irrigation Dist. | 2013-NMCA-023 | 30,824
11/02/2012 | Clinesmith v. Temmerman | 2013-NMCA-024 | 31,230
11/28/2012 | State v. Parvilus | 2013-NMCA-025 | 30,379
12/03/2012 | Serna v. Gutierrez | 2013-NMCA-026 | 30,910
12/12/2012 | State v. Webb | 2013-NMCA-027 | 31,577
11/08/2012 | State v. Sotelo | 2013-NMCA-028 | 31,061
01/11/2013 | Pecos River Open Spaces, Inc. v. Cnty. of San Miguel | 2013-NMCA-029 | 30,865
01/08/2013 | Tierra Realty Trust, L.L.C. v. Vill. of Ruidoso | 2013-NMCA-030 | 31,190
01/16/2013 | State v. Harris | 2013-NMCA-031 | 30,512
01/22/2013 | State v. Jean-Paul | 2013-NMCA-032 | 31,179
11/01/2012 | State v. Crocco | 2013-NMCA-033 | 31,498
11/08/2012 | Skowronski v. N.M. Pub. Educ. Dep't | 2013-NMCA-034 | 31,119
12/13/2012 | State v. Antonio T. | 2013-NMCA-035 | 30,827
12/13/2012 | Fowler v. Vista Care | 2013-NMCA-036 | 31,438
12/19/2012 | JaNet v. Marshall | 2013-NMCA-037 | 31,090
12/27/2012 | State v. Huettl | 2013-NMCA-038 | 31,141
01/24/2013 | Yurcic v. City of Gallup | 2013-NMCA-039 | 30,786
01/24/2013 | N.M. Bd. of Dental Health Care v. Jaime | 2013-NMCA-040 | 30,748
01/24/2013 | Zuni Indian Tribe v. McKinley Cnty. Bd. of Cnty. Comm'rs | 2013-NMCA-041 | 31,496
01/28/2013 | Garcia v. Sonoma Ranch East II, L.L.C. | 2013-NMCA-042 | 30,920
12/26/2012 | State of N.M., ex rel Foy v. Austin Capital Mgmt., Ltd. | 2013-NMCA-043 | 31,421
02/15/2013 | Williams v. Crutcher | 2013-NMCA-044 | 31,128
12/11/2012 | Edenburn v. N.M. Dep't of Health | 2013-NMCA-045 | 31,285
12/26/2012 | N.M. Cattle Growers' Assn. v. N.M. Water Quality Control Comm'n | 2013-NMCA-046 | 31,191
01/24/2013 | Town of Edgewood v. N.M. Mun. Boundary Comm'n | 2013-NMCA-047 | 30,768
02/19/2013 | La Vida Llena v. Montoya | 2013-NMCA-048 | 31,711
12/28/2012 | AFSCME v. City of Albuquerque | 2013-NMCA-049 | 31,075
02/01/2013 | CAVU Co. v. Martinez | 2013-NMCA-050 | 32,021
02/08/2013 | Estates at Desert Ridge Trails v. Vazquez | 2013-NMCA-051 | 30,944; 31,590
02/18/2013 | State v. Maples | 2013-NMCA-052 | 30,507
03/11/2013 | Luginbuhl v. City of Gallup | 2013-NMCA-053 | 31,910
12/26/2012 | Weiss v. THI of N.M. at Valle Norte, L.L.C. | 2013-NMCA-054 | 30,296
01/31/2013 | Millar v. N.M. Dep't of Workforce Solutions | 2013-NMCA-055 | 31,581
02/18/2013 | State v. Hicks | 2013-NMCA-056 | 30,370
09/26/2013 | State ex rel. CYFD v. Laura J. | 2013-NMCA-057 | 31,324; 31374
02/07/2013 | Badilla v. Wal-Mart Stores East, Inc. | 2013-NMCA-058 | 31,162
02/26/2013 | Amethyst Land Co., Inc. v. Terhune | 2013-NMCA-059 | 31,165